==> apache-kylin-2.6.5-source-release.zip: apache-kylin-2.6.5/server/src/test/java/org/apache/kylin/rest/service/KylinUserGroupServiceTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.apache.kylin.rest.service;

import java.io.IOException;
import java.util.List;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;

import com.google.common.collect.Lists;

public class KylinUserGroupServiceTest extends ServiceTestBase {

    @Autowired
    @Qualifier("userGroupService")
    KylinUserGroupService userGroupService;

    @Test
    public void testGetAllUserAuthorities() throws IOException {
        List<String> allUserAuthorities = userGroupService.getAllUserAuthorities();
        Assert.assertEquals(Lists.newArrayList("ROLE_ADMIN", "ROLE_ANALYST", "ROLE_MODELER"), allUserAuthorities);
    }
}

==> apache-kylin-3.0.1-source-release.zip: apache-kylin-3.0.1/server/src/test/java/org/apache/kylin/rest/service/KylinUserGroupServiceTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.apache.kylin.rest.service;

import java.io.IOException;
import java.util.List;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;

import com.google.common.collect.Lists;

public class KylinUserGroupServiceTest extends ServiceTestBase {

    @Autowired
    @Qualifier("userGroupService")
    KylinUserGroupService userGroupService;

    @Test
    public void testGetAllUserAuthorities() throws IOException {
        List<String> allUserAuthorities = userGroupService.getAllUserGroups();
        Assert.assertEquals(Lists.newArrayList("ALL_USERS", "ROLE_ADMIN", "ROLE_ANALYST", "ROLE_MODELER"),
                allUserAuthorities);
    }
}
